@@ -6,6 +6,7 @@ import (
 	"os"
 	"strings"
 
+	"github.com/atotto/clipboard"
 	tea "github.com/charmbracelet/bubbletea"
 	"github.com/itchyny/gojq"
 )
@@ -25,6 +26,8 @@ type queryResultMsg struct {
 
 type writeToFileMsg struct{}
 
+type copyQueryToClipboardMsg struct{}
+
 func (b *Bubble) executeQuery() tea.Cmd {
 	return func() tea.Msg {
 		query, err := gojq.Parse(b.queryinput.GetInputValue())
@@ -69,5 +72,16 @@ func (b Bubble) writeOutputToFile() tea.Cmd {
 		}
 		return writeToFileMsg{}
 	}
+}
 
+func (b Bubble) copyQueryToClipboard() tea.Cmd {
+	return func() tea.Msg {
+		err := clipboard.WriteAll(b.queryinput.GetInputValue())
+		if err != nil {
+			return errorMsg{
+				error: err,
+			}
+		}
+		return copyQueryToClipboardMsg{}
+	}
 }
